==> cog-8.x-1.4.tar.gz: cog/STARTERKIT/_readme/about-cog.md <==
# About Cog
        
#### Why was the Cog theme created? 
<a name="created"></a>
Cog was created by the Acquia Professional Services Front-end team out of the need for a standardized theme that can adapt to their wide range of projects. The PS team typically builds complex and unique designs that require the structural flexibility to adjust based on requirements. The technical approach was to create a theme that starts with Drupal theme commonalities and uses a clean code structure to extend with. The Cog theme is also utilized as measure to enforce best practices with topics like SMACSS, performance, and component-driven styles. 


#### Why should I choose the Cog for my Drupal project? 
<a name="choose"></a>
We typically recommend Cog for all of our Acquia enterprise builds, but the theme typically lends itself to custom designs and front-end requirements. We have configured the Cog theme so that your team can set up in a couple of minutes, while providing documentation for standard questions. Cog was set up with a minimal code footprint, so that various plugins and assets can be layered within. In scenarios where the designs have been tailored for other frameworks, it makes more sense to go with those options. 


#### How does Cog compare with popular frameworks like Bootstrap or Foundation? 
<a name="compare"></a>
Cog was constructed with a different approach than these front-end frameworks. It was created as a clean baseline theme for Drupal front-end developers to build upon, requiring very little setup or theme-specific knowledge. A core intent of the Cog theme is to offer a less opinionated theme that a developer can hit the ground running with, without having to work within the confines of a defined framework. Bootstrap & Foundation are frameworks that define their techniques by implementing their specific components (e.g. carousels, glyphs, etc), while Cog intends for the developer to integrate their component preference with the theme. 


#### What is the typical audience that would build with the Cog theme? 
<a name="audience"></a>
Cog is transparent about being geared for front-end developers, therefore the methodology is enforced with the tools and code that is included with it. Cog attempts to target the basic requirements to start a Drupal theme, along with the common structure to quickly understand. The styles included with Cog are intentionally slim, to help eliminate the need to layer adjustments which is common with framework-specific code. Cog uses popular front-end tools like Gulp and Susy, which establishes familiarity for most front-end developers.

==> cog-8.x-1.13.tar.gz: cog/STARTERKIT/_readme/about-cog.md <==
# About Cog
        
<a name="created"></a>
## Why was the Cog theme created? 

Cog was created by the Acquia Professional Services Front-end team out of the need for a standardized theme that can adapt to their wide range of projects. The PS team typically builds complex and unique designs that require the structural flexibility to adjust based on requirements. The technical approach was to create a theme that starts with Drupal theme commonalities and uses a clean code structure to extend with. The Cog theme is also utilized as measure to enforce best practices with topics like SMACSS, performance, and component-driven styles. 

<a name="choose"></a>
## Why should I choose the Cog for my Drupal project? 

We typically recommend Cog for all of our Acquia enterprise builds, but the theme typically lends itself to custom designs and front-end requirements. We have configured the Cog theme so that your team can set up in a couple of minutes, while providing documentation for standard questions. Cog was set up with a minimal code footprint, so that various plugins and assets can be layered within. In scenarios where the designs have been tailored for other frameworks, it makes more sense to go with those options. 

<a name="compare"></a>
## How does Cog compare with popular frameworks like Bootstrap or Foundation? 

Cog was constructed with a different approach than these front-end frameworks. It was created as a clean baseline theme for Drupal front-end developers to build upon, requiring very little setup or theme-specific knowledge. A core intent of the Cog theme is to offer a less opinionated theme that a developer can hit the ground running with, without having to work within the confines of a defined framework. Bootstrap & Foundation are frameworks that define their techniques by implementing their specific components (e.g. carousels, glyphs, etc), while Cog intends for the developer to integrate their component preference with the theme. 

<a name="audience"></a>
## What is the typical audience that would build with the Cog theme? 

Cog is transparent about being geared for front-end developers, therefore the methodology is enforced with the tools and code that is included with it. Cog attempts to target the basic requirements to start a Drupal theme, along with the common structure to quickly understand. The styles included with Cog are intentionally slim, to help eliminate the need to layer adjustments which is common with framework-specific code. Cog uses popular front-end tools like Gulp and Susy, which establishes familiarity for most front-end developers.
